# 0.3.0
* Added JS support
* Refactored generators for java-like languages
* Cleaned up a bit to satisfy pylint

# 0.2.0
* Refactored writers to generators
* Added basic tests
* Added BigDecimal PHP proxy class

# 0.1.1
* Fixed packaging issues for README.md and CHANGES.md

# 0.1.0
* Initial version
